@@ -24,7 +24,6 @@
 #include "extractorplugin.h"
 #include <tstring.h>
 #include <tstringlist.h>
-#include <tfilestream.h>
 
 namespace TagLib
 {
@@ -51,7 +50,8 @@ namespace KFileMetaData
 class TagLibExtractor : public ExtractorPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin")
+    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin"
+                      FILE "taglibextractor.json")
     Q_INTERFACES(KFileMetaData::ExtractorPlugin)
 
 public:
